@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '1.10'
-date = 'Sun Aug  2 08:17:36 2015'
+version = '2.5.1'
+date = 'Sat Apr  3 22:20:57 2021'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '1', '10', None)
+version_info = ('networkx', '2', '5.1', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2015, 8, 2, 8, 17, 36, 464945)
+date_info = datetime.datetime(2021, 4, 3, 22, 20, 57)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
